/* audio.h - interface to system audio
 *
 * Copyright 2024 Petteri Hintsanen <petterih@iki.fi>
 *
 * This file is part of abx.
 *
 * abx is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * abx is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with abx.  If not, see <http://www.gnu.org/licenses/>.
 */

/* Output device structure. */
typedef struct {
    int index;                  /* Device index for playback_init. */
    const char *name;           /* Device name. */
    int latency;                /* Default output latency. */
    int sysdefault;             /* If nonzero, this is the system
                                 * default output. */
} Audio_device;

/* Error string for the most recent error. */
extern const char *last_audio_error;

/*
 * Initialize PortAudio.
 *
 * This function must be called before any audio or playback
 * functions.
 *
 * Return 0 on success, nonzero otherwise.
 */
extern int audio_init(void);

/*
 * Shut down PortAudio.
 *
 * This function must be called before the program exits, otherwise
 * persistent resource leaks may occur.
 *
 * Return zero on success, nonzero otherwise.
 */
extern int audio_close(void);

/*
 * Get the available output devices.
 *
 * Set the given pointer to the array of devices and return the number
 * of elements in that array.
 *
 * Return -1 in case of error.
 */
extern int audio_get_outputs(const Audio_device **devices);
