/* test.h - ABX test interface
 *
 * Copyright 2010, 2016, 2024 Petteri Hintsanen <petterih@iki.fi>
 *
 * This file is part of abx.
 *
 * abx is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * abx is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with abx.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ABX_TEST_H
#define ABX_TEST_H

typedef enum {
    TEST_SAMPLE_A,
    TEST_SAMPLE_B,
    TEST_SAMPLE_NA
} Test_answer;

/*
 * Initialize a new ABX test with the given number of trials.
 *
 * Return zero on success, nonzero otherwise.
 */
extern int test_init(int ntrials);

/*
 * Close the current test.
 *
 * Release all test-related resources and mark the current test
 * invalid.
 */
extern void test_close(void);

/*
 * Get the listener's guess for trial t (zero-based).
 *
 * Return
 *   SAMPLE_A if the listener has guessed sample A,
 *   SAMPLE_B if the listener has guessed sample B,
 *   SAMPLE_NA if the listener has not yet guessed, or
 *   -1 on error.
 */
extern Test_answer test_get_guess(int t);

/*
 * Get the correct answer for trial t (zero-based).
 *
 * Return
 *   SAMPLE_A if sample A is the correct answer,
 *   SAMPLE_B if sample B is the correct answer, or
 *   -1 on error.
 */
extern Test_answer test_get_answer(int t);

/*
 * Set the guessed value to ans for trial t (zero-based).
 *
 * Return 0 on success, or nonzero on error.
 */
extern int test_set_guess(int t, Test_answer ans);

/*
 * Return the number of test trials, or -1 if no test is in progress.
 */
extern int test_get_ntrials(void);

/*
 * Return the p-value for the test statistic under the null
 * hypothesis.
 */
extern double test_get_pvalue(void);

#endif
